#
# spec file for package python-sh
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-sh
Version:        1.11
Release:        5.1
Summary:        Python subprocess interface
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/amoffat/sh
Source:         https://pypi.python.org/packages/source/s/sh/sh-%{version}.tar.gz
# PATCH-FIX-UPSTREAM test-coding-fix.patch -- Use utf-8 coding
Patch0:         test-coding-fix.patch
# PATCH-FIX-OPENSUSE test-multiple-pipes-fix.patch -- Partially disable test case
Patch1:         test-multiple-pipes-fix.patch
# PATCH-FIX-OPENSUSE test-huge-piped-data-fix.patch -- Partially disable test case
Patch2:         test-huge-piped-data-fix.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
BuildRequires:  python-setuptools

%description
sh (previously pbs) is a full-fledged subprocess
replacement for Python 2.6 - 3.2 that allows you to call
any program as if it were a function:

    from sh import ifconfig
    print ifconfig("eth0")

sh is not a collection of system commands implemented in
Python.

%prep
%setup -q -n sh-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
python setup.py build

%install
python setup.py install \
    --prefix=%{_prefix} \
    --root=%{buildroot}

%check
python test.py

%files
%defattr(-,root,root)
%doc AUTHORS.md CHANGELOG.md LICENSE.txt README.md
%{python_sitelib}/sh.py
%{python_sitelib}/sh.pyc
%{python_sitelib}/sh-%{version}-*.egg-info

%changelog
* Fri Apr 10 2015 aplanas@suse.com
- PATCH test-huge-piped-data-fix.patch
  Partially disable test case
* Wed Jan 28 2015 aplanas@suse.com
- Fix %%defattr, fixing SLE11SP3 building
* Fri Jan  2 2015 aplanas@suse.com
- Fix source URL
- Fix setup directory name
- PATCH test-coding-fix.patch
  Use utf-8 enconding in the header
- PATCH test-multiple-pipes-fix.patch
  Partially disable test case
- Remove BuildRequires python-devel
- Update to 1.11
  * partially applied functions with functools.partial have been fixed for _out and _err callbacks #160
  * _out or _err being callables no longer puts the running command in the background. to achieve the previous behavior, pass _bg=True to your command.
  * deprecated _with contexts #195
  * _timeout_signal allows you to specify your own signal to kill a timed-out process with. use a constant from the signal stdlib module. #171
  * signal exceptions can now be caught by number or name. SignalException_9 == SignalException_SIGKILL
  * child processes that timeout via _timeout raise sh.TimeoutException instead of sh.SignalExeception_9 #172
  * fixed help(sh) from the python shell and pydoc sh from the command line. #173
  * program names can no longer be shadowed by names that sh.py defines internally. removed the requirement of trailing underscores for programs that could have their names shadowed, like id.
  * memory optimization when a child process's stdin is a newline-delimted string and our bufsize is newlines
  * feature, _done special keyword argument that accepts a callback to be called when the command completes successfully #185
  * bugfix for being unable to print a baked command in python3+ #176
  * bugfix for cwd not existing and causing the child process to continue running parent process code #202
  * child process is now guaranteed to exit on exception between fork and exec.
  * fix python2 deprecation warning when running with -3 PR #165
  * bugfix where sh.py was attempting to execute directories #196, PR #189
  * only backgrounded processes will ignore SIGHUP
  * allowed ok_code to take a range object. #PR 210
  * added sh.args with context which allows overriding of all command defaults for the duration of that context.
  * added sh.pushd with context which takes a directory name and changes to that directory for the duration of that with context. PR #206
  * tests now include python 3.4 if available. tests also stop on the first python that suite that fails.
  * SIGABRT, SIGBUS, SIGFPE, SIGILL, SIGPIPE, SIGSYS have been added to the list of signals that throw an exception PR #201
  * "callable" builtin has been faked for python3.1, which lacks it.
  * "direct" option added to _piped special keyword argument, which allows sh to hand off a process's stdout fd directly to another process, instead of buffering its stdout internally, then handing it off. #119
* Fri May  2 2014 multyrealm@gmail.com
- update to 1.09
  * Fixed encoding errors related to a system encoding "ascii". GH #123.
  * Added exit_code attribute to SignalException and ErrorReturnCode exception
    classes. GH #127.
  * Making the default behavior of spawned processes to not be explicitly
    killed when the parent python process ends. Also making the spawned process
    ignore SIGHUP. GH #139.
  * Made OSX sleep hack to apply to PY2 as well as PY3.
* Mon Jan 20 2014 mvyskocil@opensuse.org
- package python-sh 1.08 for openSUSE
